# zhr_utils
1.安装
>pip install zhr_utils

2.卸载
>pip uninstall zhr_utils

3.更新
>pip install zhr_utils --upgrade

4.查看版本
>pip show zhr_utils

0.1.0 版本更新日志
1. 动态生成User-Agent
2. 过滤html标签
3. 获取当前时间
4. 写入CSV文件
5. 正则搜索匹配
6. 判断字符串是否包含中文
7. 查看当前目录是否存在某个文件
8. 请求网页获取内容
9. 检查内容是否包含违禁词
10. 请求json数据
11. 计算网页长度
12. 生成md5
13. 获取目录下所有文件路径
14. 获取文件的第一条数据
15. 获取文件的多条数据
16. 提取搜狗搜索结果数量
17. 从txt文件读取cookies
18. 生成一个指定长度的随机字符串
19. 根据中文获取全拼
20. 根据中文获取简拼
